==> pacifica-metadata-0.4.2.tar.gz: pacifica-metadata-0.4.2/README.md <==
# Pacifica Metadata Services
![PyPi](https://img.shields.io/pypi/v/pacifica-uniqueid.svg)
![Read the Docs](https://readthedocs.org/projects/pacifica-uniqueid/badge/?version=latest)
[![Build Status](https://travis-ci.org/pacifica/pacifica-metadata.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-metadata)
[![Build status](https://ci.appveyor.com/api/projects/status/ekicw5d4yxfmq1x4?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-metadata)
[![Code Climate](https://codeclimate.com/github/pacifica/pacifica-metadata/badges/gpa.svg)](https://codeclimate.com/github/pacifica/pacifica-metadata)
[![Issue Count](https://codeclimate.com/github/pacifica/pacifica-metadata/badges/issue_count.svg)](https://codeclimate.com/github/pacifica/pacifica-metadata)
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/general)
[![Docker Automated build](https://img.shields.io/docker/automated/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/builds)

This is the Pacifica Metadata service and provides Pacifica with a single
API endpoint for access to metadata.


## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-uniqueid.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
* [Configuration](docs/configuration.md) documentation.
* [Metadata Model](docs/metadatamodel.md) documentation.
* [Examples](docs/exampleusage.md) documentation.


## Contributions

Contributions are accepted on GitHub via the fork and pull request workflow.
GitHub has a good [help article](https://help.github.com/articles/using-pull-requests/)
if you are unfamiliar with this method of contributing.

==> pacifica-metadata-0.4.3.tar.gz: pacifica-metadata-0.4.3/README.md <==
# Pacifica Metadata Services
![PyPi](https://img.shields.io/pypi/v/pacifica-metadata.svg)
![Read the Docs](https://readthedocs.org/projects/pacifica-metadata/badge/?version=latest)
[![Build Status](https://travis-ci.org/pacifica/pacifica-metadata.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-metadata)
[![Build status](https://ci.appveyor.com/api/projects/status/ekicw5d4yxfmq1x4?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-metadata)
[![Code Climate](https://codeclimate.com/github/pacifica/pacifica-metadata/badges/gpa.svg)](https://codeclimate.com/github/pacifica/pacifica-metadata)
[![Issue Count](https://codeclimate.com/github/pacifica/pacifica-metadata/badges/issue_count.svg)](https://codeclimate.com/github/pacifica/pacifica-metadata)
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/general)
[![Docker Automated build](https://img.shields.io/docker/automated/pacifica/metadata.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/metadata/builds)

This is the Pacifica Metadata service and provides Pacifica with a single
API endpoint for access to metadata.


## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-metadata.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
* [Configuration](docs/configuration.md) documentation.
* [Metadata Model](docs/metadatamodel.md) documentation.
* [Examples](docs/exampleusage.md) documentation.


## Contributions

Contributions are accepted on GitHub via the fork and pull request workflow.
GitHub has a good [help article](https://help.github.com/articles/using-pull-requests/)
if you are unfamiliar with this method of contributing.
